@@ -22,10 +22,11 @@ except ImportError:
 if recommends_precompute is not None:
     from recommends.tests.tests import RecommendsTestCase
 
-from recommends.tests.models import  RecProduct, RecVote
+from recommends.tests.models import RecProduct, RecVote
 
 
 class ProductRecommendationProvider(RecommendationProvider):
+
     def get_users(self):
         return User.objects.filter(is_active=True, rec_votes__isnull=False).distinct()
 
@@ -47,10 +48,14 @@ class ProductRecommendationProvider(RecommendationProvider):
     def get_rating_item(self, rating):
         return rating.product
 
-recommendation_registry.register(RecVote, [RecProduct], ProductRecommendationProvider)
+recommendation_registry.register(
+    RecVote,
+    [RecProduct],
+    ProductRecommendationProvider)
 
 
 class GhettoRecommendationProvider(RecommendationProvider):
+
     def get_users(self):
         return User.objects.filter(is_active=True, rec_votes__isnull=False).distinct()
 
@@ -84,41 +89,79 @@ if recommends_precompute is not None and RecSysAlgorithm is not None and getattr
         }
 
         def setUp(self):
-            recommendation_registry.unregister(RecVote, [RecProduct], ProductRecommendationProvider)
-            recommendation_registry.register(RecVote, [RecProduct], RecSysRecommendationProvider)
+            recommendation_registry.unregister(
+                RecVote,
+                [RecProduct],
+                ProductRecommendationProvider)
+            recommendation_registry.register(
+                RecVote,
+                [RecProduct],
+                RecSysRecommendationProvider)
             super(RecSysAlgoTestCase, self).setUp()
 
         def tearDown(self):
             super(RecSysAlgoTestCase, self).tearDown()
-            recommendation_registry.unregister(RecVote, [RecProduct], RecSysRecommendationProvider)
-            recommendation_registry.register(RecVote, [RecProduct], ProductRecommendationProvider)
+            recommendation_registry.unregister(
+                RecVote,
+                [RecProduct],
+                RecSysRecommendationProvider)
+            recommendation_registry.register(
+                RecVote,
+                [RecProduct],
+                ProductRecommendationProvider)
 
 if recommends_precompute is not None and RedisStorage is not None and getattr(settings, 'RECOMMENDS_TEST_REDIS', False):
     class RedisRecommendationProvider(GhettoRecommendationProvider):
         storage = RedisStorage(settings=settings)
 
     class RecommendsRedisStorageTestCase(RecommendsTestCase):
+
         def setUp(self):
-            recommendation_registry.unregister(RecVote, [RecProduct], ProductRecommendationProvider)
-            recommendation_registry.register(RecVote, [RecProduct], RedisRecommendationProvider)
+            recommendation_registry.unregister(
+                RecVote,
+                [RecProduct],
+                ProductRecommendationProvider)
+            recommendation_registry.register(
+                RecVote,
+                [RecProduct],
+                RedisRecommendationProvider)
             super(RecommendsRedisStorageTestCase, self).setUp()
 
         def tearDown(self):
             super(RecommendsRedisStorageTestCase, self).tearDown()
-            recommendation_registry.unregister(RecVote, [RecProduct], RedisRecommendationProvider)
-            recommendation_registry.register(RecVote, [RecProduct], ProductRecommendationProvider)
+            recommendation_registry.unregister(
+                RecVote,
+                [RecProduct],
+                RedisRecommendationProvider)
+            recommendation_registry.register(
+                RecVote,
+                [RecProduct],
+                ProductRecommendationProvider)
 
 if recommends_precompute is not None and MongoStorage is not None and getattr(settings, 'RECOMMENDS_TEST_MONGO', False):
     class MongoRecommendationProvider(GhettoRecommendationProvider):
         storage = MongoStorage(settings=settings)
 
     class RecommendsMongoStorageTestCase(RecommendsTestCase):
+
         def setUp(self):
-            recommendation_registry.unregister(RecVote, [RecProduct], ProductRecommendationProvider)
-            recommendation_registry.register(RecVote, [RecProduct], MongoRecommendationProvider)
+            recommendation_registry.unregister(
+                RecVote,
+                [RecProduct],
+                ProductRecommendationProvider)
+            recommendation_registry.register(
+                RecVote,
+                [RecProduct],
+                MongoRecommendationProvider)
             super(RecommendsMongoStorageTestCase, self).setUp()
 
         def tearDown(self):
             super(RecommendsMongoStorageTestCase, self).tearDown()
-            recommendation_registry.unregister(RecVote, [RecProduct], MongoRecommendationProvider)
-            recommendation_registry.register(RecVote, [RecProduct], ProductRecommendationProvider)
+            recommendation_registry.unregister(
+                RecVote,
+                [RecProduct],
+                MongoRecommendationProvider)
+            recommendation_registry.register(
+                RecVote,
+                [RecProduct],
+                ProductRecommendationProvider)
